#!/bin/bash

# This helper script will handle deploying a kinesis stream
#
# /scripts/deploy-kinesis.sh
#

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "aws_account_number = \"${awsAccountNumber}\"" >> ${tfAdditionalVarsFile}

# ARN for Kinesis (if using firehose)
if [[ $KINESIS_POLICY_ARN ]]; then
  echo "Found ARN for Kinesis: \"${KINESIS_POLICY_ARN}\""
  echo "kinesis_policy_arn=\"${KINESIS_POLICY_ARN}\"" >> "${tfAdditionalVarsFile}"
fi

# ARN for s3 (if using firehose)
if [[ $S3_POLICY_ARN ]]; then
  echo "Found ARN for s3 Policy: \"${S3_POLICY_ARN}\""
  echo "s3_policy_arn=\"${S3_POLICY_ARN}\"" >> "${tfAdditionalVarsFile}"
fi

# ARN of DynamoDB tables DAX should have access to (if using dax)
if [[ $DAX_ROLE ]]; then
  tablesNames=($(printf "\"%s\" " $(env | grep "DYNAMODB_TABLE_[0-9]" | cut -d'=' -f2)))
  indexTablesNames=($(printf "\"%s/index/*\" " $(env | grep "DYNAMODB_TABLE_[0-9]" | cut -d'=' -f2)))
  tablesNames+=(${indexTablesNames[@]})
  tablesTfVar=$(echo [${tablesNames[@]}] | sed 's/ /, /g')
  echo "Found ARNs for DynamoDB tables to grant DAX access to: \"${tablesNames}\""
  echo "dynamodb_tables_arns=${tablesTfVar}" >> "${tfAdditionalVarsFile}"
fi

append_iam_roles_from_env_to_tf_vars "iam-policy" "policies" "${tfAdditionalVarsFile}"

# Show additional .auto.tfvars file
print_header "Show additional_settings.auto.tfvars"
cat "$tfAdditionalVarsFile"

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"

arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get name roleNameValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  RoleName: ${roleNameValue}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
